# --------------------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
#
# Code generated by aaz-dev-tools
# --------------------------------------------------------------------------------------------

# pylint: skip-file
# flake8: noqa

from azure.cli.core.aaz import *


class ListCredential(AAZCommand):
    """Get the endpoint access credentials to the resource.
    """

    _aaz_info = {
        "version": "2023-03-15",
        "resources": [
            ["mgmt-plane", "/{resourceuri}/providers/microsoft.hybridconnectivity/endpoints/{}/listcredentials", "2023-03-15"],
        ]
    }

    def _handler(self, command_args):
        super()._handler(command_args)
        self._execute_operations()
        return self._output()

    _args_schema = None

    @classmethod
    def _build_arguments_schema(cls, *args, **kwargs):
        if cls._args_schema is not None:
            return cls._args_schema
        cls._args_schema = super()._build_arguments_schema(*args, **kwargs)

        # define Arg Group ""

        _args_schema = cls._args_schema
        _args_schema.endpoint_name = AAZStrArg(
            options=["--endpoint-name"],
            help="The endpoint name.",
            required=True,
        )
        _args_schema.resource_uri = AAZStrArg(
            options=["--resource-uri"],
            help="The fully qualified Azure Resource manager identifier of the resource to be connected.",
            required=True,
        )
        _args_schema.expiresin = AAZIntArg(
            options=["--expiresin"],
            help="The is how long the endpoint access token is valid (in seconds).",
            default=10800,
            fmt=AAZIntArgFormat(
                maximum=10800,
                minimum=600,
            ),
        )

        # define Arg Group "ListCredentialsRequest"

        _args_schema = cls._args_schema
        _args_schema.service_name = AAZStrArg(
            options=["--service-name"],
            arg_group="ListCredentialsRequest",
            help="The name of the service. If not provided, the request will by pass the generation of service configuration token ",
            enum={"SSH": "SSH", "WAC": "WAC"},
        )
        return cls._args_schema

    def _execute_operations(self):
        self.pre_operations()
        self.EndpointsListCredentials(ctx=self.ctx)()
        self.post_operations()

    @register_callback
    def pre_operations(self):
        pass

    @register_callback
    def post_operations(self):
        pass

    def _output(self, *args, **kwargs):
        result = self.deserialize_output(self.ctx.vars.instance, client_flatten=True)
        return result

    class EndpointsListCredentials(AAZHttpOperation):
        CLIENT_TYPE = "MgmtClient"

        def __call__(self, *args, **kwargs):
            request = self.make_request()
            session = self.client.send_request(request=request, stream=False, **kwargs)
            if session.http_response.status_code in [200]:
                return self.on_200(session)

            return self.on_error(session.http_response)

        @property
        def url(self):
            return self.client.format_url(
                "/{resourceUri}/providers/Microsoft.HybridConnectivity/endpoints/{endpointName}/listCredentials",
                **self.url_parameters
            )

        @property
        def method(self):
            return "POST"

        @property
        def error_format(self):
            return "MgmtErrorFormat"

        @property
        def url_parameters(self):
            parameters = {
                **self.serialize_url_param(
                    "endpointName", self.ctx.args.endpoint_name,
                    skip_quote=True,
                    required=True,
                ),
                **self.serialize_url_param(
                    "resourceUri", self.ctx.args.resource_uri,
                    skip_quote=True,
                    required=True,
                ),
            }
            return parameters

        @property
        def query_parameters(self):
            parameters = {
                **self.serialize_query_param(
                    "expiresin", self.ctx.args.expiresin,
                ),
                **self.serialize_query_param(
                    "api-version", "2023-03-15",
                    required=True,
                ),
            }
            return parameters

        @property
        def header_parameters(self):
            parameters = {
                **self.serialize_header_param(
                    "Content-Type", "application/json",
                ),
                **self.serialize_header_param(
                    "Accept", "application/json",
                ),
            }
            return parameters

        @property
        def content(self):
            _content_value, _builder = self.new_content_builder(
                self.ctx.args,
                typ=AAZObjectType,
                typ_kwargs={"flags": {"client_flatten": True}}
            )
            _builder.set_prop("serviceName", AAZStrType, ".service_name")

            return self.serialize_content(_content_value)

        def on_200(self, session):
            data = self.deserialize_http_content(session)
            self.ctx.set_var(
                "instance",
                data,
                schema_builder=self._build_schema_on_200
            )

        _schema_on_200 = None

        @classmethod
        def _build_schema_on_200(cls):
            if cls._schema_on_200 is not None:
                return cls._schema_on_200

            cls._schema_on_200 = AAZObjectType()

            _schema_on_200 = cls._schema_on_200
            _schema_on_200.relay = AAZObjectType(
                flags={"client_flatten": True},
            )

            relay = cls._schema_on_200.relay
            relay.access_key = AAZStrType(
                serialized_name="accessKey",
                flags={"read_only": True},
            )
            relay.expires_on = AAZIntType(
                serialized_name="expiresOn",
            )
            relay.hybrid_connection_name = AAZStrType(
                serialized_name="hybridConnectionName",
                flags={"required": True},
            )
            relay.namespace_name = AAZStrType(
                serialized_name="namespaceName",
                flags={"required": True},
            )
            relay.namespace_name_suffix = AAZStrType(
                serialized_name="namespaceNameSuffix",
                flags={"required": True},
            )
            relay.service_configuration_token = AAZStrType(
                serialized_name="serviceConfigurationToken",
            )

            return cls._schema_on_200


class _ListCredentialHelper:
    """Helper class for ListCredential"""


__all__ = ["ListCredential"]
